NotEnoughSpace

Struct NotEnoughSpace 

pub struct NotEnoughSpace;
The encoder was unable to encode all the input data into the provided buffer, it might have encoded some data (or it didn’t), but there remains more to encode.