SimpleEncoder

Struct SimpleEncoder 

pub struct SimpleEncoder<T> { /* private fields */ }
This type represents the simple encoder, it wraps a EncoderCallback to delegate the encoding work to it.

Implementations

Source

impl<T: EncoderCallback> SimpleEncoder<T>

pub fn with_config( encoder: T, config: &SimpleEncoderConfig, ) -> Result<Self, EspError>

Constructs a new simple encoder with the given callback and configuration.