pub struct SimpleEncoder<T> { /* private fields */ }Expand description
This type represents the simple encoder, it wraps a EncoderCallback to delegate
the encoding work to it.
Implementations
Sourceimpl<T: EncoderCallback> SimpleEncoder<T>
impl<T: EncoderCallback> SimpleEncoder<T>
Sourcepub fn with_config(
encoder: T,
config: &SimpleEncoderConfig,
) -> Result<Self, EspError>
pub fn with_config( encoder: T, config: &SimpleEncoderConfig, ) -> Result<Self, EspError>
Constructs a new simple encoder with the given callback and configuration.